"""
Reticulum - Cloud Infrastructure Exposure Scanner
"""

__version__ = "0.6.9"
__author__ = "Jose Palanco <jose.palanco@plexicus.ai>"
__license__ = "MIT"

from .main import ExposureScanner

__all__ = ["ExposureScanner"]
